==> attal_0.8.orig.tar.gz: attal-0.8/i18n/fr/attal_ai_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AiInterface</name>
    <message>
        <source>Attal: IA client</source>
        <translation>Attal: client AI</translation>
    </message>
    <message>
        <source>Log level : Verbose</source>
        <translation>Niveau de log : Bavard</translation>
    </message>
    <message>
        <source>Verbose</source>
        <translation>Bavard</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critique</translation>
    </message>
    <message>
        <source>Quiet</source>
        <translation>Calme</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">Connecter</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <source>Log Level</source>
        <translation>Niveau de log</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Impossible de se connecter</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Déjà connecté à un serveur. Déconnectez-vous au préalable.</translation>
    </message>
    <message>
        <source>Log level : Normal</source>
        <translation>Niveau de log : Normal</translation>
    </message>
    <message>
        <source>Log level : Critical</source>
        <translation>Niveau de log : Critique</translation>
    </message>
    <message>
        <source>Log level : Quiet</source>
        <translation></translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Connexion au serveur</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Connexion au serveur</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Déconnexion</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="unfinished">Connecter</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> attal_0.9.2.orig.tar.gz: attal-0.9.2/i18n/fr/attal_ai_fr.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AiInterface</name>
    <message>
        <source>Attal: IA client</source>
        <translation>Attal: client AI</translation>
    </message>
    <message>
        <source>Log level : Verbose</source>
        <translation>Niveau de log : Bavard</translation>
    </message>
    <message>
        <source>Verbose</source>
        <translation>Bavard</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critique</translation>
    </message>
    <message>
        <source>Quiet</source>
        <translation>Calme</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">Connecter</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Déconnecter</translation>
    </message>
    <message>
        <source>Log Level</source>
        <translation>Niveau de log</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>Can&apos;t connect</source>
        <translation>Impossible de se connecter</translation>
    </message>
    <message>
        <source>You&apos;re already connected to a server. Please disconnect first.</source>
        <translation>Déjà connecté à un serveur. Déconnectez-vous au préalable.</translation>
    </message>
    <message>
        <source>Log level : Normal</source>
        <translation>Niveau de log : Normal</translation>
    </message>
    <message>
        <source>Log level : Critical</source>
        <translation>Niveau de log : Critique</translation>
    </message>
    <message>
        <source>Log level : Quiet</source>
        <translation></translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Connexion au serveur</translation>
    </message>
    <message>
        <source>&amp;Connect to server</source>
        <translation>&amp;Connexion au serveur</translation>
    </message>
    <message>
        <source>CTRL+C</source>
        <translation>CTRL+C</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Déconnexion</translation>
    </message>
    <message>
        <source>CTRL+D</source>
        <translation>CTRL+D</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Can&apos;t load theme</source>
        <translation>Impossible de charger le thème</translation>
    </message>
    <message>
        <source>Theme </source>
        <translation>Thème</translation>
    </message>
    <message>
        <source> has not been loaded successfully</source>
        <translation>n&apos;a pas été chargé correctement</translation>
    </message>
</context>
<context>
    <name>ConfigConnection</name>
    <message>
        <source>Connection to server</source>
        <translation>Connexion au serveur</translation>
    </message>
    <message>
        <source>Host : </source>
        <translation>Hôte:</translation>
    </message>
    <message>
        <source>Port : </source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Name : </source>
        <translation>Nom:</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Connecter</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
</TS>
